@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2017-2019 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 """Demo data for Lino Avanti.
 
 """
@@ -28,4 +28,4 @@ def objects():
     #     enrolment=obj, user=obj.pupil.user,
     #     date_issued=settings.SITE.demo_date(-10))
 
-    rt.models.courses.update_missing_rates()
+    rt.models.courses.update_missing_rates(rt.login('robin'))
