@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2017-2020 Rumma & Ko Ltd
+# Copyright 2017-2022 Rumma & Ko Ltd
 
 """The default :attr:`custom_layouts_module
 <lino.core.site.Site.custom_layouts_module>` for Lino Avanti.
@@ -8,12 +8,12 @@
 
 from lino.api import dd, rt, _
 
-rt.models.system.SiteConfigs.detail_layout = dd.DetailLayout("""
+rt.models.system.SiteConfigs.set_detail_layout("""
 site_company next_partner_id:10
 default_build_method simulate_today
-site_calendar default_event_type #pupil_guestrole
+site_calendar default_event_type pupil_guestrole
 max_auto_events hide_events_before
-""", size=(60, 'auto'))
+""", window_size=(60, 'auto'))
 
 rt.models.countries.Places.detail_layout = """
 name country
@@ -30,8 +30,6 @@ dd.update_field(
     rt.models.contacts.Partner, 'language',
     verbose_name=_("Contact language"))
 
-# rt.models.cv.LanguageKnowledgesByPerson.display_mode = 'grid'
-
 
 from lino_avanti.lib.avanti.roles import ClientsUser
 if dd.is_installed('calview'):
