@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2017-2018 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """The :xfile:`models.py` module for this plugin.
 
@@ -187,9 +187,6 @@ class Client(contacts.Person, BeIdCardHolder, UserAuthored,
     # skills = models.TextField(
     #     _("Other skills"), blank=True, null=True)
 
-    # client_state = ClientStates.field(
-    #     default=ClientStates.newcomer.as_callable)
-
     event_policy = dd.ForeignKey(
         'cal.EventPolicy', blank=True, null=True)
 
@@ -250,7 +247,7 @@ class Client(contacts.Person, BeIdCardHolder, UserAuthored,
         num_width = 4
         if self.ref and self.ref.upper().startswith(prefix):
             num_root = self.ref[len(prefix):].strip()
-            if len(num_root) == num_width:
+            if len(num_root) >= num_width:
                 ref_num = num_root
             else:
                 qs = self.__class__.objects.filter(
@@ -258,15 +255,21 @@ class Client(contacts.Person, BeIdCardHolder, UserAuthored,
                 qs = qs.exclude(id=self.id)
                 obj = qs.last()
                 if obj is None:
-                    last_ref = num_root.ljust(num_width, "0")
+                    next_ref = "1"
+                    # last_ref = num_root.ljust(num_width, "0")
+                    # ref_num = str(int(last_ref)+1)
                 else:
-                    last_ref = obj.ref[len(prefix):].strip()
-                ref_num = str(int(last_ref)+1)
+                    # last_ref = obj.ref[len(prefix):].strip()
+                    next_ref = obj.ref[len(prefix):].strip()
+                    num_width = max(num_width, len(next_ref))
+                    next_ref = next_ref[len(num_root):].strip()
+                    next_ref = str(int(next_ref)+1)
+                ref_num = num_root + next_ref.rjust(num_width-len(num_root), "0")
             self.ref = "{} {}".format(prefix, ref_num)
 
         # if self.national_id:
         #     ssin.ssin_validator(self.national_id)
-        super(Client, self).full_clean(*args, **kw)
+        super().full_clean(*args, **kw)
 
     def properties_list(self, *prop_ids):
         """Yields a list of the :class:`PersonProperty
@@ -281,7 +284,7 @@ class Client(contacts.Person, BeIdCardHolder, UserAuthored,
     def get_events_user(self):
         return self.get_primary_coach()
 
-    def update_cal_rset(self):
+    def get_recurrence_set(self):
         return self.event_policy
 
     def update_cal_event_type(self):
@@ -387,7 +390,7 @@ class ClientDetail(dd.DetailLayout):
 
     person = dd.Panel("""
     first_name middle_name last_name #declared_name
-    nationality:15 nationality2:15 birth_country birth_place in_belgium_since in_region_since
+    nationality:15 nationality_text:15 #nationality2:15 birth_country birth_place in_belgium_since in_region_since
     card_type #card_number card_issuer card_valid_from card_valid_until
     needs_work_permit has_contact_pcsw has_contact_work_office
     clients.ContactsByClient uploads.UploadsByProject excerpts.ExcerptsByProject:30
@@ -450,7 +453,7 @@ class ClientDetail(dd.DetailLayout):
 
     db_tab = dd.Panel("""
     changes.ChangesByMaster
-    checkdata.ProblemsByOwner:30 dupable.SimilarObjects:30
+    checkdata.MessagesByOwner:30 dupable.SimilarObjects:30
     """, label = _("Database"))
 
     career = dd.Panel("""
@@ -493,14 +496,16 @@ class Clients(contacts.Persons):
     start_date end_date #observed_event course enrolment_state client_contact_type client_contact_company
     """
 
+    # @classmethod
+    # def get_request_queryset(self, ar, **filter):
     @classmethod
-    def get_request_queryset(self, ar):
+    def get_request_queryset(self, ar, **filter):
         """This converts the values of the different parameter panel fields to
         the query filter.
 
 
         """
-        qs = super(Clients, self).get_request_queryset(ar)
+        qs = super().get_request_queryset(ar, **filter)
 
         pv = ar.param_values
         # period = [pv.start_date, pv.end_date]
@@ -575,10 +580,16 @@ class Clients(contacts.Persons):
         #~ if not obj.has_valid_card_data():
             #~ return 'red'
 
+def getter(k):
+    def func(actor, obj, ar):
+        return getattr(obj, k)
+    return func
 
-class AllClients(Clients):
+
+
+class AllClients(Clients, dd.VentilatingTable):
     auto_fit_column_widths = False
-    column_names = "client_state \
+    column_names_template = "client_state \
     starting_reason ending_reason \
     city municipality country zip_code nationality \
     #birth_date age:10 gender \
@@ -586,10 +597,34 @@ class AllClients(Clients):
     in_belgium_since needs_work_permit \
     translator_type \
     mother_tongues cef_level_de cef_level_fr cef_level_en \
-    user event_policy"
+    user event_policy {vcolumns}"
     detail_layout = None
     required_roles = dd.login_required(Explorer)
+    ventilated_column_suffix = ':10'
 
+    if dd.is_installed("trends"):
+        # For each trend stage having subject_column True, Lino adds a virtual
+        # column showing the date of the last event with that trend stage.
+
+        @classmethod
+        def get_queryset(self, ar, **filter):
+            qs = super().get_queryset(ar, **filter)
+            TrendStage = rt.models.trends.TrendStage
+            ann = dict()
+            for ts in TrendStage.objects.filter(subject_column=True):
+                k = 'event_date_' + str(ts.id)
+                ann[k] = models.Max('trend_events__event_date',
+                    filter=models.Q(trend_events__trend_stage=ts))
+            qs = qs.annotate(**ann)
+            return qs
+
+        @classmethod
+        def get_ventilated_columns(cls):
+            TrendStage = rt.models.trends.TrendStage
+            for ts in TrendStage.objects.filter(subject_column=True):
+                k = 'event_date_' + str(ts.id)
+                yield dd.VirtualField(dd.DateField(str(ts)), getter(k), sortable_by=[k])
+                # print("20231005 adding subject column", name, ts)
 
 
 class ClientsByNationality(Clients):
