@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2017-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
 
@@ -18,17 +18,20 @@
 
 from lino.projects.std.settings import *
 from lino.api.ad import _
+from lino_avanti import SETUP_INFO
 
 
 class Site(Site):
 
-    verbose_name = "Lino Avanti!"
-    # version = '2017.1.0'
-    url = "http://avanti.lino-framework.org/"
+    verbose_name = "Lino Avanti"
+    description = SETUP_INFO['description']
+    version = SETUP_INFO['version']
+    url = SETUP_INFO['url']
+
     demo_fixtures = ['std',
                      'few_languages', 'compass',
                      # 'all_countries', 'all_languages',
-                     'demo', 'demo2', 'checkdata']
+                     'demo', 'demo2', 'demo3', 'checkdata']
     user_types_module = 'lino_avanti.lib.avanti.user_types'
     workflows_module = 'lino_avanti.lib.avanti.workflows'
     custom_layouts_module = 'lino_avanti.lib.avanti.layouts'
@@ -43,13 +46,14 @@ class Site(Site):
     webdav_protocol = 'webdav'
     # beid_protocol = 'beid'
 
-    auto_configure_logger_names = 'schedule atelier django lino lino_xl lino_avanti'
+    auto_configure_logger_names = 'atelier django lino lino_xl lino_avanti'
 
     def get_installed_apps(self):
         """Implements :meth:`lino.core.site.Site.get_installed_apps`.
 
         """
         yield super(Site, self).get_installed_apps()
+        yield 'lino.modlib.help'
         yield 'lino_avanti.lib.users'
         # yield 'lino.modlib.users'
         yield 'lino_xl.lib.countries'
@@ -126,20 +130,16 @@ class Site(Site):
         yield ('weasyprint', 'header_height', 30)
         yield ('comments', 'emotion_range', 'social')
 
-    def setup_quicklinks(self, user, tb):
-        super(Site, self).setup_quicklinks(user, tb)
-        a = self.models.users.MySettings.default_action
-        tb.add_instance_action(
-            user, action=a, label=_("My settings"))
-
-        # Clients = self.models.avanti.Clients
+    def setup_quicklinks(self, ut, tb):
+        super(Site, self).setup_quicklinks(ut, tb)
         Clients = self.models.avanti.MyClients
         tb.add_action(Clients)
         tb.add_action(
             Clients.insert_action,
             label=_("New {}").format(
                 Clients.model._meta.verbose_name))
-        tb.add_action(Clients, 'find_by_beid')
+        # tb.add_action(Clients, 'find_by_beid')
+        tb.add_action(Clients.get_action_by_name('find_by_beid'))
 
         # tb.add_action(self.modules.tickets.MyTickets)
         # tb.add_action(self.modules.tickets.TicketsToTriage)
