@@ -1,12 +1,12 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2017-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2017-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
 This is the :attr:`user_types_module
 <lino.core.site.Site.user_types_module>` for :ref:`avanti`.
 
-Redefines the list of available :class:`lino.modlib.users.UserTypes`.
+Redefines the list of available :term:`user types <user type>`.
 
 """
 
@@ -17,11 +17,12 @@ from lino.api import _
 # from lino.core.roles import UserRole, SiteAdmin, SiteStaff
 from lino.core.roles import UserRole, Explorer, SiteAdmin, SiteUser
 from lino.core.roles import login_required
+from lino.core.roles import DataExporter
 from lino.modlib.users.choicelists import UserTypes
 from lino.modlib.comments.roles import CommentsUser, CommentsStaff, PrivateCommentsReader
 from lino.modlib.office.roles import OfficeUser, OfficeStaff, OfficeOperator
 from lino.modlib.checkdata.roles import CheckdataUser
-from lino.modlib.about.roles import SiteSearcher
+from lino.modlib.search.roles import SiteSearcher
 from lino_xl.lib.contacts.roles import ContactsUser, ContactsStaff
 from lino_xl.lib.cal.roles import GuestOperator
 from lino_xl.lib.polls.roles import PollsUser, PollsStaff
@@ -45,7 +46,7 @@ class Teacher(SiteUser, CoursesTeacher, OfficeUser, GuestOperator,
 
 
 class Coordinator(SiteUser, CoursesUser, OfficeOperator,
-                  CheckdataUser, ClientsNameUser):
+                  CheckdataUser, ClientsNameUser, DataExporter):
     pass
 
 
