@@ -1,7 +1,7 @@
 # Copyright 2017-2021 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from lino_xl.lib.contacts.models import *
 
 #from lino_xl.lib.beid.mixins import BeIdCardHolder
@@ -38,7 +38,7 @@ class PartnerDetail(PartnerDetail):
     """, label=_("More"))
 
     bottom_box = """
-    remarks:50 checkdata.ProblemsByOwner:30
+    remarks:50 checkdata.MessagesByOwner:30
     """
 
     # A layout for use in Belgium
@@ -78,7 +78,7 @@ class CompanyDetail(CompanyDetail, PartnerDetail):
     addr1 url
     # notes.NotesByCompany
     clients.ClientContactsByCompany
-    checkdata.ProblemsByOwner
+    checkdata.MessagesByOwner
     """, label=_("More"))
 
     address_box = """
@@ -131,7 +131,7 @@ class PersonDetail(PersonDetail, PartnerDetail):
     # personal = 'national_id card_number'
 
     bottom_box = """
-    remarks:50 checkdata.ProblemsByOwner:30
+    remarks:50 checkdata.MessagesByOwner:30
     """
 
 # Persons.set_detail_layout(PersonDetail())
