@@ -1,11 +1,10 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2017-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2017-2023 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from decimal import Decimal
 
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import pgettext_lazy as pgettext
+from lino.api import dd, pgettext, _
 
 from etgen.html import E, join_elems
 
@@ -37,7 +36,7 @@ from .choicelists import ReminderStates, ReminderDegrees
 
 #     def disable_delete(self, ar=None):
 #         # skip the is_imported_partner test
-#         return super(contacts.Partner, self).disable_delete(ar)
+#         return super().disable_delete(ar)
 
 
 # class CourseProviderDetail(contacts.CompanyDetail):
@@ -99,7 +98,7 @@ class Course(Course):
             state=EnrolmentStates.requested, needs_school=True)
 
     # def update_reminders(self, ar):
-    #     super(Course, self).update_reminders(ar)
+    #     super().update_reminders(ar)
     #     self.run_update_missing_rates()
 
     @dd.action(label = _("Update missing rates"),
@@ -173,11 +172,12 @@ class Enrolment(Enrolment):
         fields.update(
             min_missing_rate=dd.PriceField(
                 _("Missing rate"), blank=True))
-        super(Enrolment, cls).setup_parameters(fields)
+        super().setup_parameters(fields)
 
     @dd.action(label = _("Update missing rate"),
                button_text=' ☉ ')  # like gueststate 'missing'
     def update_missing_rate(self, ar):
+        # dd.logger.info("20231009 update_missing_rate %s", self)
         Guest = rt.models.cal.Guest
         Event = rt.models.cal.Event
         # flt = Event.objects.filter(
@@ -200,7 +200,7 @@ class Enrolment(Enrolment):
         ar.success(refresh=True)
 
     def disabled_fields(self, ar):
-        rv = super(Enrolment, self).disabled_fields(ar)
+        rv = super().disabled_fields(ar)
         if not ar.get_user().user_type.has_required_roles([ClientsUser]):
             rv.add("pupil")
         return rv
@@ -222,14 +222,10 @@ class Reminder(UserAuthored, Certifiable):
     enrolment = dd.ForeignKey('courses.Enrolment', editable=False)
     date_issued = dd.DateField(_("Situation on"), blank=True)
     text_body = dd.RichTextField(_("Text body"), blank=True, format='html')
-    state = ReminderStates.field(default=ReminderStates.as_callable('draft'))
-    degree = ReminderDegrees.field(
-        default=ReminderDegrees.as_callable('first'))
+    state = ReminderStates.field(default='draft')
+    degree = ReminderDegrees.field(default='first')
     remark = dd.CharField(_("Remark"), max_length=240, blank=True)
 
-    # def on_create(self, ar):
-    #     super(Reminder, self).on_create(ar)
-    #     self.date_issued = dd.today()
 
     def __str__(self):
         return "{} ({} {})".format(
@@ -250,7 +246,7 @@ class Reminder(UserAuthored, Certifiable):
                 self.date_issued = dd.today()
             else:
                 self.date_issued = ce.start_date
-        super(Reminder, self).full_clean()
+        super().full_clean()
 
 
 # class EnrolmentChecker(Checker):
@@ -305,11 +301,15 @@ class Reminder(UserAuthored, Certifiable):
 #     def get_responsible_user(self, obj):
 #         if obj.pupil and obj.pupil.user:
 #             return obj.pupil.user
-#         return super(EnrolmentChecker, self).get_responsible_user(obj)
+#         return super().get_responsible_user(obj)
 
 # EnrolmentChecker.activate()
 
 @dd.schedule_daily()
-def update_missing_rates():
+def update_missing_rates(ar):
+    # dd.logger.info("Update missing rates for all enrolments...")
     for obj in rt.models.courses.Enrolment.objects.all():
         obj.update_missing_rate()
+
+
+from .ui import *
