@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2017 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 
 """The models for this plugin.
@@ -10,7 +10,7 @@ from __future__ import unicode_literals
 
 from lino_xl.lib.households.models import *
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class Member(Member):
