@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2017 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Extends :mod:`lino.modlib.users` for :ref:`avanti`.
 
@@ -8,7 +8,7 @@
    :toctree:
 
     models
-    desktop
+    ui
     fixtures.demo
     fixtures.demo2
 
