@@ -6,14 +6,14 @@ Examples how to run these tests::
   $ python setup.py test -s tests.DocsTests.test_debts
   $ python setup.py test -s tests.DocsTests.test_docs
 """
-from unipath import Path
+from pathlib import Path
 
 ROOTDIR = Path(__file__).parent.parent
 
 SETUP_INFO = {}
 
 # load SETUP_INFO:
-filename = ROOTDIR.child('lino_avanti', 'setup_info.py')
+filename = ROOTDIR / 'lino_avanti' / 'setup_info.py'
 exec(compile(open(filename, "rb").read(), filename, 'exec'))
 
 from lino.utils.pythontest import TestCase
@@ -31,5 +31,3 @@ class PackagesTests(TestCase):
 
     def test_packages(self):
         self.run_packages_test(SETUP_INFO['packages'])
-
-
